iana_assignments: IANA IPv4 Address Space Registry
Description
This dataset contains the registry of address space assignments
for IPv4 IP addresses, as set by IANA. It consists of a data.frame containing the columns:prefix: A block of IPv4 (CIDR notation) addresses that has been registered
for a particular purpose (e.g. "100.64.0.0/10")designation: The entity the block is assigned to.date: the assignment date of the block, stored as YYYY-MM.whois: whois registry [whois.afrinic.net|whois.apnic.net|whois.arin.net|whois.lacnic.net|whois.ripe.net]status: status of the assignment [ALLOCATED|LEGACY|RESERVED]
Usage
data(iana_assignments)
format
A data frame with 256 rows and 5 variablesReferences
- Thehttp://www.iana.org/assignments/ipv4-address-space/ipv4-address-space.xhtml{
IANA page} on the IPv4 assignments.
- http://tools.ietf.org/html/rfc1466{RFC1466}.