iana_special_assignments: IANA IPv4 Special-Purpose Address Registry
Description
This dataset contains the registry of special address space assignments
for IPv4 IP addresses, as set by IANA. It consists of a data.frame containing the columns:
address_block: the full IPv4 range (chr) (e.g. "11.0.0.0/8")name: the descriptive name for the special-purpose address blockrfc: the Request for Comment (RfC) through which the special-purpose address block was requestedallocation_date: the allocation date of the block, stored as YYYY-MM.source: whether an address from the allocated special-purpose address block is valid
when used as the source address of an IP datagram that transits two devices (TRUE) or not (FALSE).destination: whether an address from the allocated special-purpose address block is valid when
used as the destination address of an IP datagram that transits two devices (TRUE) or not (FALSE).forwardable: whether a router may forward an IP datagram whose destination address is drawn from the
allocated special-purpose address block between external interfaces (TRUE) or not (FALSE).global: whether an IP datagram whose destination address is drawn from the allocated special-purpose
address block is forwardable beyond a specified administrative domain (TRUE) or not (FALSE).reserved_by_protocol. whether the special-purpose address block is reserved by IP, itself.
This value isTRUEif the RFC that created the special-purpose address block requires all compliant IP
implementations to behave in a special way when processing packets either to or from addresses contained by
the address block, andFALSEotherwise.
Usage
data(iana_special_assignments)
format
A data frame with 256 rows and 5 variablesReferences
- Thehttp://www.iana.org/assignments/ipv4-address-space/ipv4-address-space.xhtml{
IANA page} on specially assigned blocks.
- http://tools.ietf.org/html/rfc5376{RFC5376}
- http://tools.ietf.org/html/rfc6890{RFC6890}